@@ -926,8 +926,10 @@ function _pacrypt_crypt($pw, $pw_db = '') {
     if ($pw_db) {
         return crypt($pw, $pw_db);
     }
-    // Throws E_NOTICE as salt is not specified.
-    return crypt($pw);
+    // PHP8 - we have to specify a salt here....
+    $salt = substr(str_shuffle('0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'), 0, 2);
+
+    return crypt($pw, $salt);
 }
 
 /**
@@ -1577,11 +1579,18 @@ function db_connection_string() {
 
         $database_name = Config::read_string('database_name');
 
+        $dsn = 'mysql:';
         if ($socket) {
-            $dsn = "mysql:unix_socket={$socket};dbname={$database_name};charset=UTF8";
+            $dsn .= "unix_socket={$socket}";
         } else {
-            $dsn = "mysql:host={$CONF['database_host']};dbname={$database_name};charset=UTF8";
+            $dsn .= "host={$CONF['database_host']}";
         }
+
+        if (isset($CONF['database_port'])) {
+            $dsn .= ";port={$CONF['database_port']}";
+        }
+
+        $dsn .= ";dbname={$database_name};charset=UTF8";
     } elseif (db_sqlite()) {
         $db = $CONF['database_name'];
 
@@ -2305,7 +2314,7 @@ function gen_show_status($show_alias) {
             }
         }
     } else {
-        $stat_string .= ";&nbsp;";
+        $stat_string .= "&nbsp;";
     }
 
     //   $stat_string .= "<span style='background-color:green'> &nbsp; </span> &nbsp;" .
