@@ -60,7 +60,7 @@ class MailboxHandler extends PFAHandler {
         }
     }
 
-    public function init($id) : bool {
+    public function init(string $id) : bool {
         if (!parent::init($id)) {
             return false;
         }
@@ -702,14 +702,16 @@ class MailboxHandler extends PFAHandler {
         }
 
         $s_port='';
-        $create_mailbox_subdirs_hostport = Config::read_string('create_mailbox_subdirs_hostport');
-        if (!empty($create_mailbox_subdirs_hostport)) {
-            $s_port = $create_mailbox_subdirs_hostport;
-            if (intval($s_port)!=$s_port) {
-                trigger_error('The $CONF["create_mailbox_subdirs_hostport"] parameter must be an integer', E_USER_ERROR);
-                return false;
+        if (Config::has('create_mailbox_subdirs_hostport')) {
+            $create_mailbox_subdirs_hostport = Config::read('create_mailbox_subdirs_hostport');
+            if (!empty($create_mailbox_subdirs_hostport)) {
+                $s_port = $create_mailbox_subdirs_hostport;
+                if (intval($s_port)!=$s_port) {
+                    trigger_error('The $CONF["create_mailbox_subdirs_hostport"] parameter must be an integer', E_USER_ERROR);
+                    return false;
+                }
+                $s_port=':'.$s_port;
             }
-            $s_port=':'.$s_port;
         }
 
         $s='{'.$s_host.$s_port.$s_options.'}';
